
# Archimedes Blog

::::{grid} 1 1 2 2
:gutter: 3

:::{grid-item-card} Introducing Archimedes
:link: 2025/introduction
:link-type: doc

6 Oct 2025 · Announcements

A Python toolkit for deployable control systems engineering
:::

:::{grid-item-card} Spatial Mechanics
:link: 2025/spatial
:link-type: doc

20 Oct 2025 · Announcements

Inside the new `spatial` module
:::

:::{grid-item-card} Complementary IMU Filter
:link: 2025/imu_filter/imu_filter
:link-type: doc

26 Nov 2025 · Examples

An end-to-end example of simple sensor fusion with Archimedes
:::

::::
